@@ -175,17 +175,19 @@ static PyObject *fparser_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     int skip_win = 0;
     int skip_flags = 0;
     int soft_mem_limit_mb = 0;
+    int hard_mem_limit_mb = 0;
 
     static char* argnames[] = {"source", "flow_timeout", "fin_timeout", "filter",
         "snaplen", "log_level", "is_file", "skip_id", "skip_ttl", "skip_ack",
-        "skip_seq", "skip_win", "skip_flags", "soft_mem_limit",
+        "skip_seq", "skip_win", "skip_flags", "soft_mem_limit", "hard_mem_limit",
         "tcp_callback", "udp_callback", "kill_callback", NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "s|iisiiiiiiiiiiOOO",
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "s|iisiiiiiiiiiiiOOO",
             argnames, &source, &flow_timeout, &fin_timeout,
             &filter, &snaplen, &log_level, &is_file, &skip_id, &skip_ttl,
-            &skip_ack, &skip_seq, &skip_win, &skip_flags, &soft_mem_limit_mb,
-            &tcp_callback, &udp_callback, &after_kill_callback)) {
+            &skip_ack, &skip_seq, &skip_win, &skip_flags, &soft_mem_limit_mb, 
+            &hard_mem_limit_mb, &tcp_callback, &udp_callback, 
+            &after_kill_callback)) {
         return NULL;
     }
 
@@ -227,8 +229,15 @@ static PyObject *fparser_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->parser->skip_ttl = skip_ttl;
     self->parser->skip_win = skip_win;
     
-    if (soft_mem_limit_mb) {
+    if (soft_mem_limit_mb && hard_mem_limit_mb) {
+        if (hard_mem_limit_mb <= soft_mem_limit_mb) {
+            PyErr_SetString(FlowParserError, "Hard memory limit should be less "
+                    "than soft memory limit");
+            goto fail;
+        }
+        
         self->parser->soft_mem_limit = soft_mem_limit_mb * 1024 * 1024;
+        self->parser->hard_mem_limit = hard_mem_limit_mb * 1024 * 1024;
     }
 
     /* We need to be able to perform async callbacks from C to Python
