@@ -131,9 +131,12 @@ struct parser_base {
     int skip_win;
     int skip_flags;
     
-    // Soft memory limit (in bytes). If total memory exceeds this limit the 
-    // largest flow will be forcibly collected upon each collection.
+    // Soft memory limit (in bytes).
     uint64_t soft_mem_limit;
+    
+    // Hard memory limit (in bytes). If memory consumption is between the hard 
+    // and the soft memory limits flows will be collected more aggressively.
+    uint64_t hard_mem_limit;
 
     enum thread_status collector_status;
     enum thread_status dumper_status;
@@ -208,6 +211,7 @@ int close_dumper(struct parser_base *parser);
 void enqueue_flow_for_dumping(struct parser_base *parser,
         struct flow_id *id, struct flow *flow);
 size_t get_dump_queue_size(struct parser_base *parser);
+void force_synchronous_dump(struct parser_base *parser);
 
 int init_collector(struct parser_base *parser);
 int close_collector(struct parser_base *parser);
